# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.o_auth_clients_api import OAuthClientsApi


class TestOAuthClientsApi(unittest.TestCase):
    """OAuthClientsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OAuthClientsApi()

    def tearDown(self) -> None:
        pass

    def test_create_oauth_client(self) -> None:
        """Test case for create_oauth_client

        Create OAuth Client
        """
        pass

    def test_delete_oauth_client(self) -> None:
        """Test case for delete_oauth_client

        Delete OAuth Client
        """
        pass

    def test_get_oauth_client(self) -> None:
        """Test case for get_oauth_client

        Get OAuth Client
        """
        pass

    def test_list_oauth_clients(self) -> None:
        """Test case for list_oauth_clients

        List OAuth Clients
        """
        pass

    def test_patch_oauth_client(self) -> None:
        """Test case for patch_oauth_client

        Patch OAuth Client
        """
        pass


if __name__ == '__main__':
    unittest.main()
