# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.role_insights_api import RoleInsightsApi


class TestRoleInsightsApi(unittest.TestCase):
    """RoleInsightsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RoleInsightsApi()

    def tearDown(self) -> None:
        pass

    def test_create_role_insight_requests(self) -> None:
        """Test case for create_role_insight_requests

        Generate insights for roles
        """
        pass

    def test_download_role_insights_entitlements_changes(self) -> None:
        """Test case for download_role_insights_entitlements_changes

        Download entitlement insights for a role
        """
        pass

    def test_get_entitlement_changes_identities(self) -> None:
        """Test case for get_entitlement_changes_identities

        Get identities for a suggested entitlement (for a role)
        """
        pass

    def test_get_role_insight(self) -> None:
        """Test case for get_role_insight

        Get a single role insight
        """
        pass

    def test_get_role_insights(self) -> None:
        """Test case for get_role_insights

        Get role insights
        """
        pass

    def test_get_role_insights_current_entitlements(self) -> None:
        """Test case for get_role_insights_current_entitlements

        Get current entitlement for a role
        """
        pass

    def test_get_role_insights_entitlements_changes(self) -> None:
        """Test case for get_role_insights_entitlements_changes

        Get entitlement insights for a role
        """
        pass

    def test_get_role_insights_requests(self) -> None:
        """Test case for get_role_insights_requests

        Returns metadata from prior request.
        """
        pass

    def test_get_role_insights_summary(self) -> None:
        """Test case for get_role_insights_summary

        Get role insights summary information
        """
        pass


if __name__ == '__main__':
    unittest.main()
