# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.account_activities_api import AccountActivitiesApi


class TestAccountActivitiesApi(unittest.TestCase):
    """AccountActivitiesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountActivitiesApi()

    def tearDown(self) -> None:
        pass

    def test_get_account_activity(self) -> None:
        """Test case for get_account_activity

        Get Account Activity
        """
        pass

    def test_list_account_activities(self) -> None:
        """Test case for list_account_activities

        List Account Activities
        """
        pass


if __name__ == '__main__':
    unittest.main()
