# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.sod_policy_api import SODPolicyApi


class TestSODPolicyApi(unittest.TestCase):
    """SODPolicyApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SODPolicyApi()

    def tearDown(self) -> None:
        pass

    def test_create_sod_policy(self) -> None:
        """Test case for create_sod_policy

        Create SOD policy
        """
        pass

    def test_delete_sod_policy(self) -> None:
        """Test case for delete_sod_policy

        Delete SOD policy by ID
        """
        pass

    def test_delete_sod_policy_schedule(self) -> None:
        """Test case for delete_sod_policy_schedule

        Delete SOD policy schedule
        """
        pass

    def test_get_custom_violation_report(self) -> None:
        """Test case for get_custom_violation_report

        Download custom violation report
        """
        pass

    def test_get_default_violation_report(self) -> None:
        """Test case for get_default_violation_report

        Download violation report
        """
        pass

    def test_get_sod_all_report_run_status(self) -> None:
        """Test case for get_sod_all_report_run_status

        Get multi-report run task status
        """
        pass

    def test_get_sod_policy(self) -> None:
        """Test case for get_sod_policy

        Get SOD policy by ID
        """
        pass

    def test_get_sod_policy_schedule(self) -> None:
        """Test case for get_sod_policy_schedule

        Get SOD policy schedule
        """
        pass

    def test_get_sod_violation_report_run_status(self) -> None:
        """Test case for get_sod_violation_report_run_status

        Get violation report run status
        """
        pass

    def test_get_sod_violation_report_status(self) -> None:
        """Test case for get_sod_violation_report_status

        Get SOD violation report status
        """
        pass

    def test_list_sod_policies(self) -> None:
        """Test case for list_sod_policies

        List SOD policies
        """
        pass

    def test_patch_sod_policy(self) -> None:
        """Test case for patch_sod_policy

        Patch a SOD policy
        """
        pass

    def test_put_policy_schedule(self) -> None:
        """Test case for put_policy_schedule

        Update SOD Policy schedule
        """
        pass

    def test_put_sod_policy(self) -> None:
        """Test case for put_sod_policy

        Update SOD policy by ID
        """
        pass

    def test_start_sod_all_policies_for_org(self) -> None:
        """Test case for start_sod_all_policies_for_org

        Runs all policies for org
        """
        pass

    def test_start_sod_policy(self) -> None:
        """Test case for start_sod_policy

        Runs SOD policy violation report
        """
        pass


if __name__ == '__main__':
    unittest.main()
