# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictStr
from pydantic import Field
from sailpoint.beta.models.trigger_example_input import TriggerExampleInput
from sailpoint.beta.models.trigger_example_output import TriggerExampleOutput
from sailpoint.beta.models.trigger_type import TriggerType
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class Trigger(BaseModel):
    """
    Trigger
    """ # noqa: E501
    id: StrictStr = Field(description="Unique identifier of the trigger.")
    name: StrictStr = Field(description="Trigger Name.")
    type: TriggerType
    description: Optional[StrictStr] = Field(default=None, description="Trigger Description.")
    input_schema: StrictStr = Field(description="The JSON schema of the payload that will be sent by the trigger to the subscribed service.", alias="inputSchema")
    example_input: TriggerExampleInput = Field(alias="exampleInput")
    output_schema: Optional[StrictStr] = Field(default=None, description="The JSON schema of the response that will be sent by the subscribed service to the trigger in response to an event.  This only applies to a trigger type of `REQUEST_RESPONSE`.", alias="outputSchema")
    example_output: Optional[TriggerExampleOutput] = Field(default=None, alias="exampleOutput")
    __properties: ClassVar[List[str]] = ["id", "name", "type", "description", "inputSchema", "exampleInput", "outputSchema", "exampleOutput"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Trigger from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of example_input
        if self.example_input:
            _dict['exampleInput'] = self.example_input.to_dict()
        # override the default output from pydantic by calling `to_dict()` of example_output
        if self.example_output:
            _dict['exampleOutput'] = self.example_output.to_dict()
        # set to None if output_schema (nullable) is None
        # and model_fields_set contains the field
        if self.output_schema is None and "output_schema" in self.model_fields_set:
            _dict['outputSchema'] = None

        # set to None if example_output (nullable) is None
        # and model_fields_set contains the field
        if self.example_output is None and "example_output" in self.model_fields_set:
            _dict['exampleOutput'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of Trigger from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "type": obj.get("type"),
            "description": obj.get("description"),
            "inputSchema": obj.get("inputSchema"),
            "exampleInput": TriggerExampleInput.from_dict(obj.get("exampleInput")) if obj.get("exampleInput") is not None else None,
            "outputSchema": obj.get("outputSchema"),
            "exampleOutput": TriggerExampleOutput.from_dict(obj.get("exampleOutput")) if obj.get("exampleOutput") is not None else None
        })
        return _obj


