# coding: utf-8

"""
    IdentityNow V3 API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.connectors_api import ConnectorsApi


class TestConnectorsApi(unittest.TestCase):
    """ConnectorsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ConnectorsApi()

    def tearDown(self) -> None:
        pass

    def test_create_custom_connector(self) -> None:
        """Test case for create_custom_connector

        Create custom connector
        """
        pass

    def test_delete_custom_connector(self) -> None:
        """Test case for delete_custom_connector

        """
        pass

    def test_get_connector(self) -> None:
        """Test case for get_connector

        """
        pass

    def test_get_connector_correlation_config(self) -> None:
        """Test case for get_connector_correlation_config

        """
        pass

    def test_get_connector_source_config(self) -> None:
        """Test case for get_connector_source_config

        """
        pass

    def test_get_connector_source_template(self) -> None:
        """Test case for get_connector_source_template

        """
        pass

    def test_get_connector_translations(self) -> None:
        """Test case for get_connector_translations

        """
        pass

    def test_put_correlation_config(self) -> None:
        """Test case for put_correlation_config

        """
        pass

    def test_put_source_config(self) -> None:
        """Test case for put_source_config

        """
        pass

    def test_put_source_template(self) -> None:
        """Test case for put_source_template

        """
        pass

    def test_put_translations(self) -> None:
        """Test case for put_translations

        """
        pass

    def test_update_connector(self) -> None:
        """Test case for update_connector

        """
        pass


if __name__ == '__main__':
    unittest.main()
