# coding: utf-8

"""
    IdentityNow V3 API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.certifications_api import CertificationsApi


class TestCertificationsApi(unittest.TestCase):
    """CertificationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CertificationsApi()

    def tearDown(self) -> None:
        pass

    def test_get_certification_task(self) -> None:
        """Test case for get_certification_task

        Certification Task by ID
        """
        pass

    def test_get_identity_certification(self) -> None:
        """Test case for get_identity_certification

        Identity Certification by ID
        """
        pass

    def test_get_identity_certification_item_permissions(self) -> None:
        """Test case for get_identity_certification_item_permissions

        Permissions for Entitlement Certification Item
        """
        pass

    def test_get_pending_certification_tasks(self) -> None:
        """Test case for get_pending_certification_tasks

        List of Pending Certification Tasks
        """
        pass

    def test_list_certification_reviewers(self) -> None:
        """Test case for list_certification_reviewers

        List of Reviewers for certification
        """
        pass

    def test_list_identity_access_review_items(self) -> None:
        """Test case for list_identity_access_review_items

        List of Access Review Items
        """
        pass

    def test_list_identity_certifications(self) -> None:
        """Test case for list_identity_certifications

        Identity Campaign Certifications by IDs
        """
        pass

    def test_make_identity_decision(self) -> None:
        """Test case for make_identity_decision

        Decide on a Certification Item
        """
        pass

    def test_reassign_identity_certifications(self) -> None:
        """Test case for reassign_identity_certifications

        Reassign Identities or Items
        """
        pass

    def test_sign_off_identity_certification(self) -> None:
        """Test case for sign_off_identity_certification

        Finalize Identity Certification Decisions
        """
        pass

    def test_submit_reassign_certs_async(self) -> None:
        """Test case for submit_reassign_certs_async

        Reassign Certifications Asynchronously
        """
        pass


if __name__ == '__main__':
    unittest.main()
