# coding: utf-8

"""
    IdentityNow V3 API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.requestable_objects_api import RequestableObjectsApi


class TestRequestableObjectsApi(unittest.TestCase):
    """RequestableObjectsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = RequestableObjectsApi()

    def tearDown(self) -> None:
        pass

    def test_list_requestable_objects(self) -> None:
        """Test case for list_requestable_objects

        Requestable Objects List
        """
        pass


if __name__ == '__main__':
    unittest.main()
