# coding: utf-8

"""
    IdentityNow V3 API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.lifecycle_states_api import LifecycleStatesApi


class TestLifecycleStatesApi(unittest.TestCase):
    """LifecycleStatesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LifecycleStatesApi()

    def tearDown(self) -> None:
        pass

    def test_create_lifecycle_state(self) -> None:
        """Test case for create_lifecycle_state

        Create Lifecycle State
        """
        pass

    def test_delete_lifecycle_state(self) -> None:
        """Test case for delete_lifecycle_state

        Delete Lifecycle State by ID
        """
        pass

    def test_get_lifecycle_state(self) -> None:
        """Test case for get_lifecycle_state

        Retrieves Lifecycle State
        """
        pass

    def test_list_lifecycle_states(self) -> None:
        """Test case for list_lifecycle_states

        Lists LifecycleStates
        """
        pass

    def test_set_lifecycle_state(self) -> None:
        """Test case for set_lifecycle_state

        Set Lifecycle State
        """
        pass

    def test_update_lifecycle_states(self) -> None:
        """Test case for update_lifecycle_states

        Update Lifecycle State
        """
        pass


if __name__ == '__main__':
    unittest.main()
