# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.public_identities_config_api import PublicIdentitiesConfigApi


class TestPublicIdentitiesConfigApi(unittest.TestCase):
    """PublicIdentitiesConfigApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PublicIdentitiesConfigApi()

    def tearDown(self) -> None:
        pass

    def test_get_public_identity_config(self) -> None:
        """Test case for get_public_identity_config

        Get Public Identity Config
        """
        pass

    def test_update_public_identity_config(self) -> None:
        """Test case for update_public_identity_config

        Update Public Identity Config
        """
        pass


if __name__ == '__main__':
    unittest.main()
