# coding: utf-8

"""
    IdentityNow V3 API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from sailpoint.v3.models.document_type import DocumentType

class TestDocumentType(unittest.TestCase):
    """DocumentType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDocumentType(self):
        """Test DocumentType"""
        # inst = DocumentType()

if __name__ == '__main__':
    unittest.main()
