# coding: utf-8

"""
    IdentityNow V3 API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.v3.api.public_identities_api import PublicIdentitiesApi


class TestPublicIdentitiesApi(unittest.TestCase):
    """PublicIdentitiesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PublicIdentitiesApi()

    def tearDown(self) -> None:
        pass

    def test_get_public_identities(self) -> None:
        """Test case for get_public_identities

        Get a list of public identities
        """
        pass


if __name__ == '__main__':
    unittest.main()
