# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.iai_peer_group_strategies_api import IAIPeerGroupStrategiesApi


class TestIAIPeerGroupStrategiesApi(unittest.TestCase):
    """IAIPeerGroupStrategiesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IAIPeerGroupStrategiesApi()

    def tearDown(self) -> None:
        pass

    def test_get_peer_group_outliers(self) -> None:
        """Test case for get_peer_group_outliers

        Identity Outliers List
        """
        pass


if __name__ == '__main__':
    unittest.main()
