# coding: utf-8

"""
    IdentityNow Beta API

    Use these APIs to interact with the IdentityNow platform to achieve repeatable, automated processes with greater scalability. These APIs are in beta and are subject to change. We encourage you to join the SailPoint Developer Community forum at https://developer.sailpoint.com/discuss to connect with other developers using our APIs.

    The version of the OpenAPI document: 3.1.0-beta
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sailpoint.beta.api.non_employee_lifecycle_management_api import NonEmployeeLifecycleManagementApi


class TestNonEmployeeLifecycleManagementApi(unittest.TestCase):
    """NonEmployeeLifecycleManagementApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NonEmployeeLifecycleManagementApi()

    def tearDown(self) -> None:
        pass

    def test_approve_non_employee_request(self) -> None:
        """Test case for approve_non_employee_request

        Approve a Non-Employee Request
        """
        pass

    def test_create_non_employee_record(self) -> None:
        """Test case for create_non_employee_record

        Create Non-Employee Record
        """
        pass

    def test_create_non_employee_request(self) -> None:
        """Test case for create_non_employee_request

        Create Non-Employee Request
        """
        pass

    def test_create_non_employee_source(self) -> None:
        """Test case for create_non_employee_source

        Create Non-Employee Source
        """
        pass

    def test_create_non_employee_source_schema_attributes(self) -> None:
        """Test case for create_non_employee_source_schema_attributes

        Create Non-Employee Source Schema Attribute
        """
        pass

    def test_delete_non_employee_record(self) -> None:
        """Test case for delete_non_employee_record

        Delete Non-Employee Record
        """
        pass

    def test_delete_non_employee_record_in_bulk(self) -> None:
        """Test case for delete_non_employee_record_in_bulk

        Delete Multiple Non-Employee Records
        """
        pass

    def test_delete_non_employee_request(self) -> None:
        """Test case for delete_non_employee_request

        Delete Non-Employee Request
        """
        pass

    def test_delete_non_employee_schema_attribute(self) -> None:
        """Test case for delete_non_employee_schema_attribute

        Delete Non-Employee Source's Schema Attribute
        """
        pass

    def test_delete_non_employee_source(self) -> None:
        """Test case for delete_non_employee_source

        Delete Non-Employee Source
        """
        pass

    def test_delete_non_employee_source_schema_attributes(self) -> None:
        """Test case for delete_non_employee_source_schema_attributes

        Delete all custom schema attributes
        """
        pass

    def test_export_non_employee_records(self) -> None:
        """Test case for export_non_employee_records

        Exports Non-Employee Records to CSV
        """
        pass

    def test_export_non_employee_source_schema_template(self) -> None:
        """Test case for export_non_employee_source_schema_template

        Exports Source Schema Template
        """
        pass

    def test_get_non_employee_approval(self) -> None:
        """Test case for get_non_employee_approval

        Get a non-employee approval item detail
        """
        pass

    def test_get_non_employee_approval_summary(self) -> None:
        """Test case for get_non_employee_approval_summary

        Get Summary of Non-Employee Approval Requests
        """
        pass

    def test_get_non_employee_bulk_upload_status(self) -> None:
        """Test case for get_non_employee_bulk_upload_status

        Bulk upload status on source
        """
        pass

    def test_get_non_employee_record(self) -> None:
        """Test case for get_non_employee_record

        Get a Non-Employee Record
        """
        pass

    def test_get_non_employee_request(self) -> None:
        """Test case for get_non_employee_request

        Get a Non-Employee Request
        """
        pass

    def test_get_non_employee_request_summary(self) -> None:
        """Test case for get_non_employee_request_summary

        Get Summary of Non-Employee Requests
        """
        pass

    def test_get_non_employee_schema_attribute(self) -> None:
        """Test case for get_non_employee_schema_attribute

        Get Schema Attribute Non-Employee Source
        """
        pass

    def test_get_non_employee_source(self) -> None:
        """Test case for get_non_employee_source

        Get a Non-Employee Source
        """
        pass

    def test_get_non_employee_source_schema_attributes(self) -> None:
        """Test case for get_non_employee_source_schema_attributes

        List Schema Attributes Non-Employee Source
        """
        pass

    def test_import_non_employee_records_in_bulk(self) -> None:
        """Test case for import_non_employee_records_in_bulk

        Imports, or Updates, Non-Employee Records
        """
        pass

    def test_list_non_employee_approval(self) -> None:
        """Test case for list_non_employee_approval

        Get List of Non-Employee Approval Requests
        """
        pass

    def test_list_non_employee_records(self) -> None:
        """Test case for list_non_employee_records

        List Non-Employee Records
        """
        pass

    def test_list_non_employee_requests(self) -> None:
        """Test case for list_non_employee_requests

        List Non-Employee Requests
        """
        pass

    def test_list_non_employee_sources(self) -> None:
        """Test case for list_non_employee_sources

        List Non-Employee Sources
        """
        pass

    def test_patch_non_employee_record(self) -> None:
        """Test case for patch_non_employee_record

        Patch Non-Employee Record
        """
        pass

    def test_patch_non_employee_schema_attribute(self) -> None:
        """Test case for patch_non_employee_schema_attribute

        Patch Non-Employee Source's Schema Attribute
        """
        pass

    def test_patch_non_employee_source(self) -> None:
        """Test case for patch_non_employee_source

        Patch a Non-Employee Source
        """
        pass

    def test_reject_non_employee_request(self) -> None:
        """Test case for reject_non_employee_request

        Reject a Non-Employee Request
        """
        pass

    def test_update_non_employee_record(self) -> None:
        """Test case for update_non_employee_record

        Update Non-Employee Record
        """
        pass


if __name__ == '__main__':
    unittest.main()
